// ----------------------------------------------------------------------
// MenuTextEdit.h
// Jason Hughes
// Origin Systems
// 1998
// ----------------------------------------------------------------------
// This set of classes handle text input of various types within the
// menu system.  The base class (MenuTextEdit) provides the basic
// functionality which the derived classes are built from.  For most
// uses, the derived classes should be used.  Complex input structures
// can be built from the MenuTextEdit class.
// ----------------------------------------------------------------------

#ifndef MENUTEXTEDIT_H
#define MENUTEXTEDIT_H

// ----------------------------------------------------------------------

#include "MenuText.h"

class Iff;

// ----------------------------------------------------------------------

class MenuTextEdit : public MenuText
{
private:

	enum
	{
		MAX_CHAR = 256
	};

private:

	Timer  cursorTimer;
	bool   drawCursor;
	Font   *editFont;
	int    maxLength;
	int    enterEvent;
	int    escapeEvent;
	bool   isEditable;
	String preservedString;
	int    minimumNumChars;
	IoWin  *oldCapturer;
	bool   characterAllowed[MAX_CHAR];
	bool   deleteStringWhenCaptureStarts; // defaults to false

private:

	void init(void);

protected:

	MenuTextEdit(const MenuTextEdit &);
	MenuTextEdit &operator =(const MenuTextEdit &);

public:

	MenuTextEdit(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff=NULL);
	virtual ~MenuTextEdit(void);

	void                load(Iff *iff);

	virtual IoResult    event(IoEventStruct *event);
	virtual void        menuDraw(int x, int y) const;

	virtual void        setTextString(const String &newText);
	virtual void        setTextString(int newTextInt);
	virtual Font       *getFont(void) const;
	void                setMaxLength(int newMaxLength);
	void                eraseText(void);
	void                startCapturing(void);
	void                startCapturingButPreserveOldStringInCaseTheUserHitsEscape(void);
	void                stopCapturing(void);
	bool                isCapturing(void) const;
	void                setDeleteStringWhenCaptureStarts(bool deleteString = true);
};

// ======================================================================

inline bool MenuTextEdit::isCapturing(void) const
{
	return isEditable;
}

// ----------------------------------------------------------------------

inline void MenuTextEdit::setMaxLength(int newMaxLength)
{
	maxLength = newMaxLength;
}

// ======================================================================

#endif